==> chromium-76.0.3809.38.tar.xz: chromium-76.0.3809.38/components/download/public/common/download_features.cc <==
// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "components/download/public/common/download_features.h"

#include "build/build_config.h"

namespace download {
namespace features {

const base::Feature kUseDownloadOfflineContentProvider{
    "UseDownloadOfflineContentProvider", base::FEATURE_DISABLED_BY_DEFAULT};

const base::Feature kDownloadAutoResumptionNative {
  "DownloadsAutoResumptionNative",
#if defined(OS_ANDROID)
      base::FEATURE_DISABLED_BY_DEFAULT
#else
      base::FEATURE_DISABLED_BY_DEFAULT
#endif
};

const base::Feature kParallelDownloading {
  "ParallelDownloading",
#if defined(OS_ANDROID)
      base::FEATURE_ENABLED_BY_DEFAULT
#else
      base::FEATURE_DISABLED_BY_DEFAULT
#endif
};

const base::Feature kDownloadDBForNewDownloads{
    "DownloadDBForNewDownloads", base::FEATURE_ENABLED_BY_DEFAULT};

#if defined(OS_ANDROID)
const base::Feature kRefreshExpirationDate{"RefreshExpirationDate",
                                           base::FEATURE_ENABLED_BY_DEFAULT};
#endif

const base::Feature kPreventDownloadsWithSamePath{
    "PreventDownloadsWithSamePath", base::FEATURE_DISABLED_BY_DEFAULT};

const base::Feature kUseInProgressDownloadManagerForDownloadService{
    "UseInProgressDownloadManagerForDownloadService",
    base::FEATURE_DISABLED_BY_DEFAULT};

const base::Feature kAllowDownloadResumptionWithoutStrongValidators{
    "AllowDownloadResumptionWithoutStrongValidators",
    base::FEATURE_DISABLED_BY_DEFAULT};
}  // namespace features

}  // namespace download

==> chromium-77.0.3836.0.tar.xz: chromium-77.0.3836.0/components/download/public/common/download_features.cc <==
// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "components/download/public/common/download_features.h"

#include "build/build_config.h"

namespace download {
namespace features {

const base::Feature kUseDownloadOfflineContentProvider{
    "UseDownloadOfflineContentProvider", base::FEATURE_DISABLED_BY_DEFAULT};

const base::Feature kDownloadAutoResumptionNative {
  "DownloadsAutoResumptionNative",
#if defined(OS_ANDROID)
      base::FEATURE_DISABLED_BY_DEFAULT
#else
      base::FEATURE_DISABLED_BY_DEFAULT
#endif
};

const base::Feature kParallelDownloading {
  "ParallelDownloading",
#if defined(OS_ANDROID)
      base::FEATURE_ENABLED_BY_DEFAULT
#else
      base::FEATURE_DISABLED_BY_DEFAULT
#endif
};

const base::Feature kDownloadDBForNewDownloads{
    "DownloadDBForNewDownloads", base::FEATURE_ENABLED_BY_DEFAULT};

#if defined(OS_ANDROID)
const base::Feature kRefreshExpirationDate{"RefreshExpirationDate",
                                           base::FEATURE_ENABLED_BY_DEFAULT};
#endif

const base::Feature kPreventDownloadsWithSamePath{
    "PreventDownloadsWithSamePath", base::FEATURE_DISABLED_BY_DEFAULT};

const base::Feature kUseInProgressDownloadManagerForDownloadService{
    "UseInProgressDownloadManagerForDownloadService",
    base::FEATURE_DISABLED_BY_DEFAULT};

const base::Feature kAllowDownloadResumptionWithoutStrongValidators{
    "AllowDownloadResumptionWithoutStrongValidators",
    base::FEATURE_DISABLED_BY_DEFAULT};

const base::Feature kUseParallelRequestsForUnknwonRangeSupport{
    "UseParallelRequestForUnknownRangeSupport",
    base::FEATURE_DISABLED_BY_DEFAULT};

}  // namespace features

}  // namespace download
